@@ -3,12 +3,15 @@ import json
 import os
 from os.path import *
 import glob
+import gzip
 from typing import Callable, Union
 from ..utils.click import PERCENTAGE
 from ..utils.env_keys import REPORT_ERROR_KEY
 from ..utils.http_client import LaunchableClient
 from ..utils.token import parse_token
 from ..testpath import TestPath
+from ..utils.session import read_session
+from .record.session import session
 
 # TODO: rename files and function accordingly once the PR landscape
 
@@ -26,8 +29,6 @@ from ..testpath import TestPath
     'session_id',
     help='Test session ID',
     type=str,
-    # validate session_id under debug mode
-    required=os.getenv(REPORT_ERROR_KEY),
 )
 @click.option(
     '--base',
@@ -36,10 +37,31 @@ from ..testpath import TestPath
     type=click.Path(exists=True, file_okay=False),
     metavar="DIR",
 )
+@click.option(
+    '--build',
+    'build_name',
+    help='build name',
+    type=str,
+    metavar='BUILD_NAME'
+)
 @click.pass_context
-def subset(context, target, session_id, base_path):
+def subset(context, target, session_id, base_path: str, build_name: str):
     token, org, workspace = parse_token()
 
+    if session_id and build_name:
+        raise click.UsageError(
+            'Only one of --build or --session should be specified')
+
+    if not session_id:
+        if build_name:
+            session_id = read_session(build_name)
+            if not session_id:
+                context.invoke(session, build_name=build_name, save_session_file=True, print_session=False)
+                session_id = read_session(build_name)
+        else:
+            raise click.UsageError(
+                'Either --build or --session has to be specified')
+
     # TODO: placed here to minimize invasion in this PR to reduce the likelihood of
     # PR merge hell. This should be moved to a top-level class
     class Optimize:
@@ -141,6 +163,7 @@ def subset(context, target, session_id, base_path):
                 try:
                     headers = {
                         "Content-Type": "application/json",
+                        "Content-Encoding": "gzip",
                     }
 
                     payload = {
@@ -156,8 +179,8 @@ def subset(context, target, session_id, base_path):
                         org, workspace)
 
                     client = LaunchableClient(token)
-                    res = client.request("post", path, data=json.dumps(
-                        payload).encode(), headers=headers)
+                    res = client.request("post", path, data=gzip.compress(json.dumps(
+                        payload).encode()), headers=headers)
                     res.raise_for_status()
 
                     output = res.json()["testPaths"]
